@@ -1,7 +1,7 @@
 package File::RsyBak;
 
-our $DATE = '2015-10-29'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2017-02-03'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -243,6 +243,7 @@ sub _backup {
         ($opts->{extra_rsync_opts} ? map { shell_quote($_), " " }
              @{$opts->{extra_rsync_opts}} : ()),
         "-a --del --force --ignore-errors --ignore-existing ",
+        ($log->is_debug ? "-v " : ""),
         ((-e "$target->{abs_path}/current") ?
              "--link-dest ".shell_quote("$target->{abs_path}/current")." "
                  : ""),
@@ -377,7 +378,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-This document describes version 0.30 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-10-29.
+This document describes version 0.31 of File::RsyBak (from Perl distribution File-RsyBak), released on 2017-02-03.
 
 =head1 SYNOPSIS
 
@@ -491,94 +492,6 @@ on those platforms.
 
 =back
 
-=head1 FUNCTIONS
-
-
-=head2 backup(%args) -> [status, msg, result, meta]
-
-Backup files/directories with histories, using rsync.
-
-Examples:
-
- backup( source => "/home/jajang/mydata", target => "/backup/jajang/mydata");
-
-
-Result:
-
- [
-   500,
-   "Error: Can't create target directory : No such file or directory",
- ]
-
-
-This function is not exported by default, but exportable.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<backup> => I<bool> (default: 1)
-
-Whether to do backup or not.
-
-If backup=1 and rotate=0 then will only create new backup without rotating
-histories.
-
-=item * B<extra_dir> => I<bool>
-
-Whether to force creation of source directory in target.
-
-If set to 1, then backup(source => '/a', target => '/backup/a') will create
-another 'a' directory in target, i.e. /backup/a/current/a. Otherwise, contents
-of a/ will be directly copied under /backup/a/current/.
-
-Will always be set to 1 if source is more than one, but default to 0 if source
-is a single directory. You can set this to 1 to so that behaviour when there is
-a single source is the same as behaviour when there are several sources.
-
-=item * B<extra_rsync_opts> => I<array[str]>
-
-Pass extra options to rsync command.
-
-Extra options to pass to rsync command when doing backup. Note that the options
-will be shell quoted, , so you should pass it unquoted, e.g. ['--exclude',
-'/Program Files'].
-
-=item * B<histories> => I<array[int]> (default: [-7,4,3])
-
-Histories/history levels.
-
-Specifies number of backup histories to keep for level 1, 2, and so on. If
-number is negative, specifies number of days to keep instead (regardless of
-number of histories).
-
-=item * B<rotate> => I<bool> (default: 1)
-
-Whether to do rotate after backup or not.
-
-If backup=0 and rotate=1 then will only do history rotating.
-
-=item * B<source>* => I<str>
-
-Director(y|ies) to backup.
-
-=item * B<target>* => I<str>
-
-Backup destination.
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
 =head1 HOW IT WORKS
 
 =head2 First-time backup
@@ -672,20 +585,102 @@ histories too will accumulate:
 Finally, TARGET/hist3.<timestamp1> will be deleted after
 TARGET/hist3.<timestamp85> comes along.
 
-=head1 HISTORY
+=head1 FUNCTIONS
 
-The idea for this module came out in 2006 as part of the Spanel hosting control
-panel project. We need a daily backup system for shared hosting accounts that
-supports histories and cherry-picking. Previously we had been using a
-Python-based script B<rdiff-backup>. It was not very robust, the script chose to
-exit on many kinds of non-fatal errors instead of ignoring the errors and
-continuning backup. It was also very slow: on a server with hundreds of accounts
-with millions of files, backup process often took 12 hours or more. After
-evaluating several other solutions, we realized that nothing beats the raw
-performance of rsync. Thus we designed a simple backup system based on it.
 
-First public release of this module is in Feb 2011. I have since used this
-script in various production servers as well as personal PCs/laptops.
+=head2 backup(%args) -> [status, msg, result, meta]
+
+Backup files/directories with histories, using rsync.
+
+Examples:
+
+=over
+
+=item * Example #1:
+
+ backup( source => "/home/jajang/mydata", target => "/backup/jajang/mydata");
+
+Result:
+
+ [
+   500,
+   "Error: Can't create target directory : No such file or directory",
+   undef,
+   {},
+ ]
+
+Backup /home/jajang/mydata to /backup/jajang/mydata using the default number of
+histories ([-7, 4, 3]).
+
+=back
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<backup> => I<bool> (default: 1)
+
+Whether to do backup or not.
+
+If backup=1 and rotate=0 then will only create new backup without rotating
+histories.
+
+=item * B<extra_dir> => I<bool>
+
+Whether to force creation of source directory in target.
+
+If set to 1, then backup(source => '/a', target => '/backup/a') will create
+another 'a' directory in target, i.e. /backup/a/current/a. Otherwise, contents
+of a/ will be directly copied under /backup/a/current/.
+
+Will always be set to 1 if source is more than one, but default to 0 if source
+is a single directory. You can set this to 1 to so that behaviour when there is
+a single source is the same as behaviour when there are several sources.
+
+=item * B<extra_rsync_opts> => I<array[str]>
+
+Pass extra options to rsync command.
+
+Extra options to pass to rsync command when doing backup. Note that the options
+will be shell quoted, , so you should pass it unquoted, e.g. ['--exclude',
+'/Program Files'].
+
+=item * B<histories> => I<array[int]> (default: [-7,4,3])
+
+Histories/history levels.
+
+Specifies number of backup histories to keep for level 1, 2, and so on. If
+number is negative, specifies number of days to keep instead (regardless of
+number of histories).
+
+=item * B<rotate> => I<bool> (default: 1)
+
+Whether to do rotate after backup or not.
+
+If backup=0 and rotate=1 then will only do history rotating.
+
+=item * B<source>* => I<str>
+
+Director(y|ies) to backup.
+
+=item * B<target>* => I<str>
+
+Backup destination.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
 
 =head1 FAQ
 
@@ -726,15 +721,20 @@ From your backup host:
 Or alternatively, you can backup on SRC-HOST locally first, then send the
 resulting backup to BAK-HOST.
 
-=head1 SEE ALSO
+=head1 HISTORY
 
-L<File::Backup>
+The idea for this module came out in 2006 as part of the Spanel hosting control
+panel project. We need a daily backup system for shared hosting accounts that
+supports histories and cherry-picking. Previously we had been using a
+Python-based script B<rdiff-backup>. It was not very robust, the script chose to
+exit on many kinds of non-fatal errors instead of ignoring the errors and
+continuning backup. It was also very slow: on a server with hundreds of accounts
+with millions of files, backup process often took 12 hours or more. After
+evaluating several other solutions, we realized that nothing beats the raw
+performance of rsync. Thus we designed a simple backup system based on it.
 
-L<File::Rotate::Backup>
-
-L<Snapback2>, which is a backup system using the same basic principle (rsync
-snapshots), created in as early as 2004 (or earlier) by Mike Heins. Do check it
-out. I wish I had found it first before reinventing it in 2006 :-)
+First public release of this module is in Feb 2011. I have since used this
+script in various production servers as well as personal PCs/laptops.
 
 =head1 HOMEPAGE
 
@@ -752,13 +752,23 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<File::Backup>
+
+L<File::Rotate::Backup>
+
+L<Snapback2>, which is a backup system using the same basic principle (rsync
+snapshots), created in as early as 2004 (or earlier) by Mike Heins. Do check it
+out. I wish I had found it first before reinventing it in 2006 :-)
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
